==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pl/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Użytkownik anulował zapotrzebowanie na sprzęt na stronie www',
    'a_user_requested' => 'Użytkownik zamówił pozycję na stronie internetowej',
    'accessory_name' => 'Nazwa sprzętu:',
    'additional_notes' => 'Dodatkowe notatki:',
    'admin_has_created' => 'Administrator utworzył dla Ciebie konto na stronie :web.',
    'asset' => 'Sprzęt:',
    'asset_name' => 'Nazwa sprzętu:',
    'asset_requested' => 'Wystosowane zapotrzebowanie na sprzęt',
    'asset_tag' => 'Numer sprzętu:',
    'assigned_to' => 'Przypisane do',
    'best_regards' => 'Pozdrawiam',
    'canceled' => 'Anulowane:',
    'checkin_date' => 'Data otrzymania:',
    'checkout_date' => 'Data przypisania:',
    'click_to_confirm' => 'Proszę kliknąć na ten link aby potwierdzić swoje konto na :web:',
    'click_on_the_link_accessory' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_on_the_link_asset' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'Confirm_Asset_Checkin' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_Accessory_Checkin' => 'Potwierdź przyjęcie akcesorium',
    'Confirm_accessory_delivery' => 'Potwierdź otrzymanie akcesorium',
    'Confirm_license_delivery' => 'Potwierdź otrzymanie licencji',
    'Confirm_asset_delivery' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_consumable_delivery' => 'Potwierdź otrzymanie materiałów eksploatacyjnych',
    'current_QTY' => 'Bieżąca ilość',
    'Days' => 'Dni',
    'days' => 'Dni',
    'expecting_checkin_date' => 'Spodziewana data przyjęcia:',
    'expires' => 'Wygasa',
    'Expiring_Assets_Report' => 'Raport wygasających sprzętów.',
    'Expiring_Licenses_Report' => 'Raport Wygasających Licencji.',
    'hello' => 'Cześć',
    'hi' => 'Cześć',
    'i_have_read' => 'Przeczytałem i zgadzam się z warunkami użytkowania oraz potwierdzam otrzymanie niniejszej pozycji.',
    'item' => 'Pozycja:',
    'Item_Request_Canceled' => 'Anulowano zamówioną pozycję',
    'Item_Requested' => 'Pozycja Zamówiona',
    'link_to_update_password' => 'Proszę kliknąć na poniższy link, aby zaktualizować swoje hasło na :web:',
    'login_first_admin' => 'Zaloguj się do aplikacji Snipe-IT przy użyciu poniższych poświadczeń:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Raport niskiego stanu zasobów',
    'min_QTY' => 'Min. ilość',
    'name' => 'Nazwa',
    'new_item_checked' => 'Nowy przedmiot przypisany do Ciebie został zwrócony, szczegóły poniżej.',
    'password' => 'Hasło:',
    'password_reset' => 'Resetowanie hasła',

    'read_the_terms' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej.',
    'read_the_terms_and_click' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej i kliknąć na link poniżej aby potwierdzić zapoznanie się z warunkami  użytkowania i otrzymania sprzętu.',
    'requested' => 'Zamówione:',
    'reset_link' => 'Link resetujący Twoje hasło',
    'reset_password' => 'Kliknij tutaj aby zresetować swoje hasło:',
    'serial' => 'Nr seryjny',
    'supplier' => 'Dostawca',
    'tag' => 'Tag',
    'test_email' => 'Testowy email z :web',
    'test_mail_text' => 'To jest wiadomość testowa z aplikacji Snipe-IT Asset Management System. Jeśli otrzymałeś ją - poczta działa :)',
    'the_following_item' => 'Następujący sprzęt został otrzymany: ',
    'low_inventory_alert' => 'Istnieje: liczba przedmiot, który jest poniżej minimalnej ilości zapasów lub wkrótce ta wartość będzie niska. | Istnieją: policz przedmioty, które są poniżej minimalnej ilości zapasów lub wkrótce te wartości będą niskie.',
    'assets_warrantee_alert' => 'Istnieje: liczba aktywo z wygasającą gwarancją w ciągu następnych: dni progowe. | Istnieje: liczba aktyw z wygasającą gwarancją w ciągu następnych: dni progowe.',
    'license_expiring_alert' => 'Istnieje: liczba licencja wygasająca w ciągu następnych: dni progowe. | Istnieje: liczba licencji wygasających w ciągu następnych: dni progowe.',
    'to_reset' => 'Aby zresetować hasło na :web, wypełnij ten formularz:',
    'type' => 'Typ',
    'upcoming-audits' => 'Istnieje :count aktywa, które nadchodzą do rewizji w ciągu :threshold days.|Istnieje :count aktywów, które nadchodzą do rewizji w ciągu :threshold dni.',
    'user' => 'Użytkownik',
    'username' => 'Nazwa użytkownika',
    'welcome' => 'Witaj :name',
    'welcome_to' => 'Witamy na :web!',
    'your_credentials' => 'Twoje poświadczenia :web',
    'Accessory_Checkin_Notification' => 'Akcesorium zwrócono',
    'Asset_Checkin_Notification' => 'Sprzęt zwrócono',
    'License_Checkin_Notification' => 'Akcesorium zwrócono',
    'Expected_Checkin_Report' => 'Oczekiwano raportu kontroli aktywów',
    'Expected_Checkin_Notification' => 'Przypomnienie: :name sprawdza termin zbliżający się',
    'Expected_Checkin_Date' => 'Zasób przypisany Tobie ma być zwrócony w dniu :date',
    'your_assets' => 'Zobacz swój sprzęt'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pl/mail.php <==
<?php

return [
    'a_user_canceled' => 'Użytkownik anulował zapotrzebowanie na sprzęt na stronie www',
    'a_user_requested' => 'Użytkownik zamówił pozycję na stronie internetowej',
    'accessory_name' => 'Nazwa sprzętu:',
    'additional_notes' => 'Dodatkowe notatki:',
    'admin_has_created' => 'Administrator utworzył dla Ciebie konto na stronie :web.',
    'asset' => 'Sprzęt:',
    'asset_name' => 'Nazwa sprzętu:',
    'asset_requested' => 'Wystosowane zapotrzebowanie na sprzęt',
    'asset_tag' => 'Tag sprzętu',
    'assigned_to' => 'Przypisane do',
    'best_regards' => 'Pozdrawiam',
    'canceled' => 'Anulowane:',
    'checkin_date' => 'Data otrzymania:',
    'checkout_date' => 'Data przypisania:',
    'click_to_confirm' => 'Proszę kliknąć na ten link aby potwierdzić swoje konto na :web:',
    'click_on_the_link_accessory' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'click_on_the_link_asset' => 'Proszę kliknąć link poniżej aby potwierdzić otrzymanie sprzętu.',
    'Confirm_Asset_Checkin' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_Accessory_Checkin' => 'Potwierdź przyjęcie akcesorium',
    'Confirm_accessory_delivery' => 'Potwierdź otrzymanie akcesorium',
    'Confirm_license_delivery' => 'Potwierdź otrzymanie licencji',
    'Confirm_asset_delivery' => 'Potwierdź otrzymanie sprzętu',
    'Confirm_consumable_delivery' => 'Potwierdź otrzymanie materiałów eksploatacyjnych',
    'current_QTY' => 'Bieżąca ilość',
    'Days' => 'Dni',
    'days' => 'Dni',
    'expecting_checkin_date' => 'Spodziewana data przyjęcia:',
    'expires' => 'Wygasa',
    'Expiring_Assets_Report' => 'Raport wygasających sprzętów.',
    'Expiring_Licenses_Report' => 'Raport Wygasających Licencji.',
    'hello' => 'Cześć',
    'hi' => 'Cześć',
    'i_have_read' => 'Przeczytałem i zgadzam się z warunkami użytkowania oraz potwierdzam otrzymanie niniejszej pozycji.',
    'item' => 'Pozycja:',
    'Item_Request_Canceled' => 'Anulowano zamówioną pozycję',
    'Item_Requested' => 'Pozycja Zamówiona',
    'link_to_update_password' => 'Proszę kliknąć na poniższy link, aby zaktualizować swoje hasło na :web:',
    'login_first_admin' => 'Zaloguj się do aplikacji Snipe-IT przy użyciu poniższych poświadczeń:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Raport niskiego stanu zasobów',
    'min_QTY' => 'Min. ilość',
    'name' => 'Nazwa',
    'new_item_checked' => 'Nowy przedmiot przypisany do Ciebie został zwrócony, szczegóły poniżej.',
    'password' => 'Hasło:',
    'password_reset' => 'Resetowanie hasła',

    'read_the_terms' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej.',
    'read_the_terms_and_click' => 'Proszę przeczytać warunki użytkowania przedstawione poniżej i kliknąć na link poniżej aby potwierdzić zapoznanie się z warunkami  użytkowania i otrzymania sprzętu.',
    'requested' => 'Zamówione:',
    'reset_link' => 'Link resetujący Twoje hasło',
    'reset_password' => 'Kliknij tutaj aby zresetować swoje hasło:',
    'serial' => 'Nr seryjny',
    'supplier' => 'Dostawca',
    'tag' => 'Tag',
    'test_email' => 'Testowy email z :web',
    'test_mail_text' => 'To jest wiadomość testowa z aplikacji Snipe-IT Asset Management System. Jeśli otrzymałeś ją - poczta działa :)',
    'the_following_item' => 'Następujący sprzęt został otrzymany: ',
    'low_inventory_alert' => 'Istnieje: liczba przedmiot, który jest poniżej minimalnej ilości zapasów lub wkrótce ta wartość będzie niska. | Istnieją: policz przedmioty, które są poniżej minimalnej ilości zapasów lub wkrótce te wartości będą niskie.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Istnieje: liczba licencja wygasająca w ciągu następnych: dni progowe. | Istnieje: liczba licencji wygasających w ciągu następnych: dni progowe.',
    'to_reset' => 'Aby zresetować hasło na :web, wypełnij ten formularz:',
    'type' => 'Typ',
    'upcoming-audits' => 'Istnieje :count aktywa, które nadchodzą do rewizji w ciągu :threshold days.|Istnieje :count aktywów, które nadchodzą do rewizji w ciągu :threshold dni.',
    'user' => 'Użytkownik',
    'username' => 'Nazwa użytkownika',
    'welcome' => 'Witaj :name',
    'welcome_to' => 'Witamy na :web!',
    'your_credentials' => 'Twoje poświadczenia :web',
    'Accessory_Checkin_Notification' => 'Akcesorium zwrócono',
    'Asset_Checkin_Notification' => 'Sprzęt zwrócono',
    'License_Checkin_Notification' => 'Akcesorium zwrócono',
    'Expected_Checkin_Report' => 'Oczekiwano raportu kontroli aktywów',
    'Expected_Checkin_Notification' => 'Przypomnienie: :name sprawdza termin zbliżający się',
    'Expected_Checkin_Date' => 'Zasób przypisany Tobie ma być zwrócony w dniu :date',
    'your_assets' => 'Zobacz swój sprzęt',
];
